## 公募基金公司

接口：fund_company

描述：获取公募基金管理人列表

积分：用户需要1500积分才可以调取，一次可以提取全部数据。具体请参阅积分获取办法 

输入参数

无，可提取全部

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| name | str | Y | 基金公司名称 |
| shortname | str | Y | 简称 |
| short_enname | str | N | 英文缩写 |
| province | str | Y | 省份 |
| city | str | Y | 城市 |
| address | str | Y | 注册地址 |
| phone | str | Y | 电话 |
| office | str | Y | 办公地址 |
| website | str | Y | 公司网址 |
| chairman | str | Y | 法人代表 |
| manager | str | Y | 总经理 |
| reg_capital | float | Y | 注册资本 |
| setup_date | str | Y | 成立日期 |
| end_date | str | Y | 公司终止日期 |
| employees | float | Y | 员工总数 |
| main_business | str | Y | 主要产品及业务 |
| org_code | str | Y | 组织机构代码 |
| credit_code | str | Y | 统一社会信用代码 |

接口示例

```python
pro = ts.pro_api()

df = pro.fund_company()
```

数据示例

```python
name                   shortname          province   city  \
0           北京广能投资基金管理有限公司        广能基金       北京    北京市   
```